@@ -13,7 +13,7 @@ pub mod sizeofs;
 pub mod writer;
 
 pub use crate::errors::{Error, Result};
-pub use crate::message::{MessageRead, MessageWrite};
+pub use crate::message::{MessageInfo, MessageRead, MessageWrite};
 pub use crate::reader::{deserialize_from_slice, BytesReader};
 pub use crate::writer::{serialize_into_slice, BytesWriter, Writer, WriterBackend};
 
